// DigitalEvent.java

/*
This software is part of the Aplu FtController package.
It is Open Source Free Software, so you may
- run the code for any purpose
- study how the code works and adapt it to your needs
- integrate all or parts of the code in your own programs
- redistribute copies of the code
- improve the code and release your improvements to the public
However the use of the code is entirely your responsibility.
 */

package ch.aplu.ftcontroller;

/**
 * A class to retrieve event information when the DigitalListener callbacks are fired.
 */
public class DigitalEvent 
{
  protected int value;
  protected int mask;

  protected DigitalEvent()
  {
  }
  
  /**
   * Returns a bit pattern that reflects the current states of the input ports:
   * I1->bit 0 (LSB),...,I8->bit 7 (MSB), higher bits set to zero.
   * @return a bit pattern of the port states (integer 0..255)
   */
  public int getValue()
  {
    return value;
  }

  /**
   * Returns a bit pattern that reflects which ports have changed their state.
   * I1->bit 0 (LSB),...,I8->bit 7 (MSB), higher bits set to zero.
   * @return a bit pattern of the ports that changed their state (integer 0..255)
   */
  public int getMask()
  {
    return mask;
  }

  /**
   * Returns the current state of the given port
   * @param portNb the port number (1..8) to survey for changes
   * @return true, if the port is set to 1; false, if set to 0
   */
  public boolean isPortChanged(int portNb)
  {
    int bitValue = 1 << (portNb - 1);
    return ((mask & bitValue) != 0);
  }  

  /** 
   * Returns the state of the given port.
   * @param portNb the port number (1..8) to survey
   * @return true, if state 1 (on); flase, if the state is 0 (off)
   */
  public boolean isPortOn(int portNb)
  {
    int bitValue = 1 << (portNb - 1);
    return ((value & bitValue) != 0);
  }
}
